errorpages

package
v0.0.0-...-c34d2c7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 4, 2019 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package errorpages standardizes common html error pages across our application.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Asset

func Asset(name string) ([]byte, error)

Asset loads and returns the asset for the given name. It returns an error if the asset could not be found or could not be loaded.

func AssetDir

func AssetDir(name string) ([]string, error)

AssetDir returns the file names below a certain directory embedded in the file by go-bindata. For example if you run go-bindata on data/... and data contains the following hierarchy:

data/
  foo.txt
  img/
    a.png
    b.png

then AssetDir("data") would return []string{"foo.txt", "img"} AssetDir("data/img") would return []string{"a.png", "b.png"} AssetDir("foo.txt") and AssetDir("notexist") would return an error AssetDir("") will return []string{"data"}.

func AssetInfo

func AssetInfo(name string) (os.FileInfo, error)

AssetInfo loads and returns the asset info for the given name. It returns an error if the asset could not be found or could not be loaded.

func AssetNames

func AssetNames() []string

AssetNames returns the names of the assets.

func Forbidden

func Forbidden(res http.ResponseWriter)

Forbidden writes a 403 message

func GatewayTimeout

func GatewayTimeout(res http.ResponseWriter)

GatewayTimeout writes a 504 message

func InternalServerError

func InternalServerError(res http.ResponseWriter)

InternalServerError writes a 500 message

func InternalServerErrorWithSentry

func InternalServerErrorWithSentry(res http.ResponseWriter, sentryErrorID, sentryPublicDSN string)

InternalServerErrorWithSentry shows an error page and collects user feedback for debugging purposes

func MustAsset

func MustAsset(name string) []byte

MustAsset is like Asset but panics when Asset would return an error. It simplifies safe initialization of global variables.

func NotFound

func NotFound(res http.ResponseWriter)

NotFound writes a 404 message

func RestoreAsset

func RestoreAsset(dir, name string) error

RestoreAsset restores an asset under the given directory

func RestoreAssets

func RestoreAssets(dir, name string) error

RestoreAssets restores an asset under the given directory recursively

func TooManyRequests

func TooManyRequests(res http.ResponseWriter)

TooManyRequests writes a 429 message

Types

This section is empty.

Jump to